@@ -4,6 +4,7 @@ c             hadron A collision by Lund
 
 #include  "Zptcl.h"
 #include  "Zcode.h"
+
 c
         record /ptcl/ pj, a(*)
         integer ia,iz, np
@@ -75,9 +76,8 @@ c         *****************************************************
 c
        subroutine cfritiof(pj, ia, iz,  a, np)
        implicit none
-c----       include '../../Zptcl.h'
+#include  "ZstrangeCode.h"
 #include  "Zptcl.h"
-c----       include '../../Zcode.h'
 #include  "Zcode.h"
        integer ia, iz, np
        record /ptcl/ pj, a(*)
@@ -104,7 +104,22 @@ c
 
       integer mst
       real*4 par
-      character*70   msg
+      character*90   msg
+c ---------------------------------------------------------------------
+c              Debug-def    discard-def  notify-def use-strg-flg  halt
+c     debug       o             x           o           o          x
+c     discard     x             o           x           o          x
+c     other       x             x           o           x          o
+c ---------------------------------------------------------------------
+c
+#ifdef USE_STRANGEFLAG
+      logical strangeCode
+#endif
+
+#ifdef NOTIFY_STRANGECODE
+      integer irnow(2)  ! to store random num. seed for this event
+#endif
+
       common/ludat1C/mst(40),par(80)
 c  -----------------------------------------------
       integer kidn, icg, l, kk, ktmp, ctmp, pap
@@ -259,18 +274,26 @@ c        --- fix projectile --------------
                  iproty=18
              elseif(icg .eq. -1)then
                  iproty=-18
-             elseif(pj.subcode .eq. k0l) then
+             elseif(abs(pj.subcode) .eq. k0l) then
 c                  k0l
-                 iproty=38
-             elseif(pj.subcode .eq. k0s) then
+                 iproty=sign(38, pj.subcode)
+             elseif(abs(pj.subcode) .eq. k0s) then
 c                  k0s
-                 iproty=37
+                 iproty=sign(37, pj.subcode)
              endif
           else
              write(msg,*) ' ptcl code=',kidn,' not acceptable in ',
      *                  ' cfritiof '
              call cerrorMsg(msg, 0)
           endif
+#ifdef USE_STRANGEFLAG
+c           skip particles of undefined code; 
+          do while (.true.)
+             strangeCode = .false.
+#endif
+#ifdef NOTIFY_STRANGECODE
+          call rnd1s(irnow)  ! save current seed for strange code
+#endif
 c                generate ptcls
           call ingeboC
 c                make decay of unstable ptcls
@@ -330,17 +353,16 @@ c                    n_b
                   ctmp=0
                   pap=antip
 c                -------------------  kaon  0
-              elseif(kk .eq. 37) then
-c          pap: -1--> k0 short, -2-->k0 long
-c                    kos
+              elseif(abs(kk) .eq. 37) then
+c                     kos
                   ktmp=kkaon
                   ctmp=0
-                  pap=k0s
-              elseif(kk .eq. 38) then
+                  pap=sign(k0s, kk)
+              elseif(abs(kk) .eq. 38) then
 c                    k0l
                   ktmp=kkaon
                   ctmp=0
-                  pap=k0l
+                  pap=sign(k0l, kk)
               elseif(kk .eq.  7) then
 c                    e-
                   ktmp=kelec
@@ -362,9 +384,30 @@ c                   mu +
                   ctmp= 1
                   pap= antip
               else
+#ifdef NOTIFY_STRANGECODE
                   write(msg,*) ' ptcl code=',kk, ' from ingebo',
      *            ' not acceptable in cfritiof'
-                  call cerrorMsg(msg, 0)
+                  call cerrorMsg(msg, 1)
+                  write(msg, *) ' input cosmos ptcl code=',
+     *             pj.code, ' subcode=', pj.subcode, ' chg=',
+     *             pj.charge, ' target A,Z=',ia, iz
+                  call cerrorMsg(msg, 1)
+                  write(msg, *)  ' E=', pj.fm.p(4), ' mass=',pj.mass,
+     *            ' seed of the event= ', irnow
+                  call cerrorMsg(msg, 1)
+                  write(msg, *) ' its E=', et,' it is ', l, '-th ',
+     *            ' among ',n, ' ptlcs'
+                  call cerrorMsg(msg, 1)
+#ifdef DEBUG_STRANGECODE
+                  msg = ' The event is discarded'
+                  call cerrorMsg(msg, 1)
+#endif
+#endif
+#ifdef USE_STRANGEFLAG
+                  strangeCode = .true.
+#else
+                  call cerrorMsg('execution halted', 0)
+#endif
               endif
 c              
               np=np+1
@@ -374,6 +417,12 @@ c
               a(np).fm.p(2) = p(l,2)
               a(np).fm.p(3) = p(l,3)
            enddo
+#ifdef  USE_STRANGEFLAG
+           if(.not. strangeCode) goto 100
+           enddo
+ 100       continue
+#endif
+
         end
         block data cblkfritio
          common /indataC/ elab,rots,nap,nzp,r0p,nat,nzt,r0t,iflspv,bmin,
@@ -523,7 +572,7 @@ c                    n_b
                   ctmp=0.
                   pap=antip
 c                -------------------  k0
-              elseif(kk .eq. 24 .or. kk .eq. 25) then
+              elseif(kk .eq. 24) then
                   ktmp=kkaon
                   ctmp =0
                   call rndc(u)
@@ -532,6 +581,16 @@ c                -------------------  k0
                   else
                      pap = k0l
                   endif
+               elseif(kk .eq. 25) then
+c                     k0b
+                  ktmp=kkaon
+                  ctmp =0
+                  call rndc(u)
+                  if(u .lt. 0.5) then
+                     pap = -k0s
+                  else
+                     pap = -k0l
+                  endif
               elseif(kk .eq. 3)  then
 c                    e-
                   ktmp = kelec
