@@ -1,5 +1,7 @@
 c       main program of cosmos
+#include "ZcosmosBD.h"
       program Cosmos
+#include "ZcosmosExt.h"
          call cmanager   ! call Manager for Cosmos Simulation
       end
 
