@@ -6,28 +6,28 @@ c	(->	------------------------------------
 	character*70  PrimaryFile  !1  Primary Spectrum data file (full or relative path)
 	character*70  CutOffFile   !1  Geomagnetic cut-off file
 	character*70  ContFile     !1  Job continuation information file  (full or relative path).
-                                   !   default is ../Data/.contInfo.  This will be created when job
+                                   !   default is "ContInfo".  This will be created when job
                                    !   is finished normally.
-	character*70  SkeletonFile !1  Skeleton information file  (full or relative path). created if  Job =
-                                   !   'skeleton'. Default is ../Data/skeletonParam
-                                   !   This is the Namelist data which should be used as input at the time of
-                                   !   Job='flesh' after modifying parameters in &Param there.
-	character*10  Job          !1  What kind of job you are going to do.
-                                   !   =' ' (default).  nothing special.
+	character*70  SkeletonFile !1   Skeleton information file (full or relative path). created if Job =
+                                   !    'skeleton'. Default is 'skeletonParam'.  This is the Namelist data
+                                   !     referred by Cosmos automatically  if Job='flesh' is specified. For
+                                   !     Job='flesh', you have to modify some part of  this file.
+	character*10  Job          !1  What kind of job you are going to do.\newline
+                                   !   =' ' (default).  nothing special.\newline
                                    !   ='skeleton'.  Makes skeleton. Later you can add AS, follow particles
                                    !        to a lower energy and/or to a deeper depth, by giving Job='flesh'.
-                                   !        'skeletonParm' is automatically created.
+                                   !        'skeletonParm' is automatically created.\newline
                                    !   ='flesh'. Using information created by Job='skeleton' and the 
                                    !             initial random number for each event, you can add AS,
                                    !             follow particles to a lower energy and/or to a deeper depth.
 	                           !             The namelist parameters you give should be 'skeletonParam'
 	                           !             with some necessary modification.
-        character*70  SeedFile     !1  The path to a file name to contain the initial random numbers for each 
-                                   !   event. If this is non-blank, the seeds are always writen in this file.
-                                   !   If your job is skeleton making or fleshing, this must be given.
-                                   !   Default is '../Data/seed'.
-                                   !   This file is opened automatically.  This will help when a job
-                                   !   crashes.
+        character*70  SeedFile     !1   File to  contain the initial random numbers for those events to 
+                                   !    which you want to flesh. You can create the file by calling
+                                   !     cwriteSeed in a user hook routine (say, in chookEnEvent) at 
+                                   !     skeleton making time. Default is 'Seed'.  For a normal run with
+                                   !      Job=' ', if SeedFile is not ' ',  two integer initial random numbers
+                                   !      and the event number are  automatically output on the speicfied disk file.
         integer       SeedFileDev  !2   logical device number of SeedFile.
 	logical       Cont         !1  If T, continuation from a previous job is assumed. Contfile content is used.
 	integer       InitRN       !1  Initial random number seed. 2 integers.
