@@ -13,8 +13,8 @@ c         by putting  Es = 0.
      +, InclusiveFile, IncreaseXsec, KEminObs2, Knockon, Kpicns, Kpilog
      +, LpmBremEmin, LpmPairEmin, LundPara, MagBrem, MagBremEmin
      +, MagChgDist, MagD, MagE, MagN, MagPair, MagPairEmin, MaxComptonE
-     +, MaxPhotoE, Moliere, Mudirp, MulLow, NoOfSites2, OffsetHeight
-     +, PathLimit, PrevEventNo, PtAvFrag, PtAvNonInteNuc, RatioToE0
-     +, RecoilKineMinE, Reverse, SeedFileDev, SucInt, SucPw, TempDev
-     +, TraceDev, Truncc, Truncn, Truncx, UpsilonMin, X0
-     +, XaxisFromSouth
+     +, MaxPhotoE, Moliere, MuBr, MuNI, MuPr, Mudirp, MulLow
+     +, NoOfSites2, OffsetHeight, PathLimit, PrevEventNo, PtAvFrag
+     +, PtAvNonInteNuc, RatioToE0, RecoilKineMinE, Reverse, SeedFileDev
+     +, SucInt, SucPw, TempDev, TraceDev, Truncc, Truncn, Truncx
+     +, UpsilonMin, X0, XaxisFromSouth
