@@ -158,6 +158,12 @@ c
      *               prm.each(label).subcode,
      *               prm.each(label).charge,
      *               prm.particle)        
+
+         if(prm.each(label).code .eq. kmuon) then
+c            give polarization for muon primary
+            call csetMuonPol(0.d0)
+         endif
+
          if(prm.each(label).etype .eq. 'e/p' .or.
      *      prm.each(label).etype .eq. 'e') then
             prm.particle.fm.p(4) = seinGeV
@@ -290,3 +296,4 @@ c
         prm = Prim
         end
 
+
